@@ -108,7 +108,7 @@ async def test_query_tool_success():
                 fin.writelines([f"doc{i}"])
         with (
             patch("vectorcode.mcp_main.get_project_config") as mock_get_project_config,
-            patch("vectorcode.mcp_main.get_collection") as mock_get_collection,
+            patch("vectorcode.mcp_main.get_collection", return_value=mock_collection),
             patch(
                 "vectorcode.mcp_main.ClientManager._create_client",
                 return_value=mock_client,
@@ -125,7 +125,7 @@ async def test_query_tool_success():
             mock_load_config_file.return_value = mock_config
             mock_get_project_config.return_value = mock_config
 
-            mock_get_collection.return_value = mock_collection
+            # mock_get_collection.return_value = mock_collection
 
             mock_get_query_result_files.return_value = [
                 os.path.join(temp_dir, i) for i in ("file1.py", "file2.py")
@@ -149,17 +149,11 @@ async def test_query_tool_collection_access_failure():
             side_effect=Exception("Failed to connect"),
         ),
     ):
-        with pytest.raises(McpError) as exc_info:
+        with pytest.raises(McpError):
             await query_tool(
                 n_query=2, query_messages=["keyword1"], project_root="/valid/path"
             )
 
-        assert exc_info.value.error.code == 1
-        assert (
-            "Failed to access the collection at /valid/path. Use `list_collections` tool to get a list of valid paths for this field."
-            in exc_info.value.error.message
-        )
-
 
 @pytest.mark.asyncio
 async def test_query_tool_no_collection():
@@ -174,17 +168,11 @@ async def test_query_tool_no_collection():
     ):
         mock_get_collection.return_value = None
 
-        with pytest.raises(McpError) as exc_info:
+        with pytest.raises(McpError):
             await query_tool(
                 n_query=2, query_messages=["keyword1"], project_root="/valid/path"
             )
 
-        assert exc_info.value.error.code == 1
-        assert (
-            "Failed to access the collection at /valid/path. Use `list_collections` tool to get a list of valid paths for this field."
-            in exc_info.value.error.message
-        )
-
 
 @pytest.mark.asyncio
 async def test_vectorise_tool_invalid_project_root():
@@ -249,15 +237,9 @@ async def test_vectorise_files_collection_access_failure():
         ),
         patch("vectorcode.mcp_main.get_collection"),
     ):
-        with pytest.raises(McpError) as exc_info:
+        with pytest.raises(McpError):
             await vectorise_files(paths=["file.py"], project_root="/valid/path")
 
-        assert exc_info.value.error.code == 1
-        assert (
-            "Failed to create the collection at /valid/path"
-            in exc_info.value.error.message
-        )
-
 
 @pytest.mark.asyncio
 async def test_vectorise_files_with_exclude_spec():
